Collection class

No Description

Annotations
  • @freezed

Constructors

Collection({required String name, required CollectionStatus status, @JsonKey.new(includeIfNull: false) int? size, required int dimension})
Factory constructor for Collection
const
factory
Collection.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $CollectionCopyWith<Collection>
no setterinherited
dimension int
The dimensionality of the collection.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the collection.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
The size of the collection in bytes.
no setterinherited
status CollectionStatus
The current status of the collection
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema