ConfigureIndexRequest class

No Description

Annotations
  • @freezed

Constructors

ConfigureIndexRequest({@Default.new(1) int replicas, @JsonKey.new(name: 'pod_type', includeIfNull: false, unknownEnumValue: JsonKey.nullForUndefinedEnumValue) PodType? podType})
Factory constructor for ConfigureIndexRequest
const
factory
ConfigureIndexRequest.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $ConfigureIndexRequestCopyWith<ConfigureIndexRequest>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
podType PodType?
An enumeration of the available pod types.
no setterinherited
replicas int
The desired number of replicas for the index.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema
replicasDefaultValue → const int
Validation constants
replicasMinValue → const int