source property
The name of the index to use as the source of the collection.
Implementation
String get source => throw _privateConstructorUsedError;
The name of the index to use as the source of the collection.
String get source => throw _privateConstructorUsedError;