Index class

No Description

Available extensions
Annotations
  • @freezed

Constructors

Index({required IndexDatabase database, required IndexStatus status})
Factory constructor for Index
const
factory
Index.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $IndexCopyWith<Index>
no setterinherited
database IndexDatabase
Summary of index properties and metadata
no setterinherited
environment String

Available on Index, provided by the ExtensionIndex extension

no setter
hashCode int
The hash code for this object.
no setterinherited
name String

Available on Index, provided by the ExtensionIndex extension

no setter
projectId String

Available on Index, provided by the ExtensionIndex extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status IndexStatus
Information regarding status of the index.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema