IndexStatsRequest class

No Description

Annotations
  • @freezed

Constructors

IndexStatsRequest({@JsonKey.new(includeIfNull: false) Map<String, dynamic>? filter})
Factory constructor for IndexStatsRequest
const
factory
IndexStatsRequest.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $IndexStatsRequestCopyWith<IndexStatsRequest>
no setterinherited
filter Map<String, dynamic>?
If defined, the operation only returns statistics for vectors that satisfy the filter.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema