IndexStatus class

Information regarding status of the index.

Annotations
  • @freezed

Constructors

IndexStatus({required String host, required int port, @JsonKey.new(unknownEnumValue: IndexState.terminating) required IndexState state, required bool ready})
Factory constructor for IndexStatus
const
factory
IndexStatus.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $IndexStatusCopyWith<IndexStatus>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
host String
The host of the index.
no setterinherited
port int
The port of this index.
no setterinherited
ready bool
Indicator of index readiness.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state IndexState
The current state of a index.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema