NamespaceStats class

A summary of the contents of a namespace.

Annotations
  • @freezed

Constructors

NamespaceStats({required int vectorCount})
Factory constructor for NamespaceStats
const
factory
NamespaceStats.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $NamespaceStatsCopyWith<NamespaceStats>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vectorCount int
The number of vectors stored in this namespace.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

propertyNames → const List<String>
List of all property names of schema