PineconeClient class

Client for Pinecone API (v.1.1.0)

No description

Constructors

PineconeClient({String apiKey = '', String? baseUrl, Map<String, String> headers = const {}, Map<String, dynamic> queryParams = const {}, Client? client})
Creates a new PineconeClient instance.

Properties

apiKey String
Authentication related variables
final
baseUrl String?
Override base URL (default: server url defined in spec)
final
client → Client
HTTP client for requests
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Global headers to be sent with every request
final
queryParams Map<String, dynamic>
Global query parameters to be sent with every request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureIndex({String environment = 'us-west1-gcp-free', required String indexName, required ConfigureIndexRequest request}) Future<void>
Configure index
createCollection({String environment = 'us-west1-gcp-free', required CreateCollectionRequest request}) Future<void>
Create collection
createIndex({String environment = 'us-west1-gcp-free', required CreateIndexRequest request}) Future<void>
Create index
deleteCollection({String environment = 'us-west1-gcp-free', required String collectionName}) Future<void>
Delete collection
deleteIndex({String environment = 'us-west1-gcp-free', required String indexName}) Future<void>
Delete index
deleteVectors({required String indexName, required String projectId, required String environment, required DeleteRequest request}) Future<void>
Delete vectors
describeCollection({String environment = 'us-west1-gcp-free', required String collectionName}) Future<Collection>
Describe collection
describeIndex({String environment = 'us-west1-gcp-free', required String indexName}) Future<Index>
Describe index
describeIndexStats({required String indexName, required String projectId, required String environment, IndexStatsRequest? request}) Future<IndexStats>
Describe index stats
endSession() → void
Close the HTTP client and end session
fetchVectors({required String indexName, required String projectId, required String environment, required List<String> ids, String? namespace}) Future<FetchResponse>
Fetch vectors
listCollections({String environment = 'us-west1-gcp-free'}) Future<List<String>>
List collections
listIndexes({String environment = 'us-west1-gcp-free'}) Future<List<String>>
List indexes
makeRequest({required String baseUrl, required String path, required HttpMethod method, Map<String, dynamic> queryParams = const {}, Map<String, String> headerParams = const {}, bool isMultipart = false, String requestType = '', String responseType = '', Object? body}) Future<Response>
Reusable request method
makeRequestStream({required String baseUrl, required String path, required HttpMethod method, Map<String, dynamic> queryParams = const {}, Map<String, String> headerParams = const {}, bool isMultipart = false, String requestType = '', String responseType = '', Object? body}) Future<StreamedResponse>
Reusable request stream method
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(BaseRequest request) Future<BaseRequest>
Middleware for HTTP requests (user can override)
onResponse(Response response) Future<Response>
Middleware for HTTP responses (user can override)
onStreamedResponse(StreamedResponse response) Future<StreamedResponse>
Middleware for HTTP streamed responses (user can override)
queryVectors({required String indexName, required String projectId, required String environment, required QueryRequest request}) Future<QueryResponse>
Query vectors
toString() String
A string representation of this object.
inherited
updateVector({required String indexName, required String projectId, required String environment, required UpdateRequest request}) Future<void>
Update vector
upsertVectors({required String indexName, required String projectId, required String environment, required UpsertRequest request}) Future<UpsertResponse>
Upsert vectors

Operators

operator ==(Object other) bool
The equality operator.
inherited