PodType enum

An enumeration of the available pod types.

Inheritance
Available extensions

Values

s1X1 → const PodType
s1X2 → const PodType
s1X4 → const PodType
s1X8 → const PodType
p1X1 → const PodType
p1X2 → const PodType
p1X4 → const PodType
p1X8 → const PodType
p2X1 → const PodType
p2X2 → const PodType
p2X4 → const PodType
p2X8 → const PodType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PodType>
A constant List of the values in this enum, in order of their declaration.