SparseVector class
No Description
- Annotations
-
- @freezed
Constructors
-
SparseVector({@JsonKey.new(includeIfNull: false) List<
int> ? indices, @JsonKey.new(includeIfNull: false) List<double> ? values}) -
Factory constructor for SparseVector
constfactory
-
SparseVector.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $SparseVectorCopyWith<
SparseVector> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
→ List<
int> ? -
The indices of the sparse data.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
double> ? -
The corresponding values of the sparse data, which must be the same length as the indices.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema