UpdateRequest class

No Description

Annotations
  • @freezed

Constructors

UpdateRequest({required String id, @JsonKey.new(includeIfNull: false) List<double>? values, @JsonKey.new(includeIfNull: false) SparseVector? sparseValues, @JsonKey.new(includeIfNull: false) Map<String, dynamic>? setMetadata, @JsonKey.new(includeIfNull: false) String? namespace})
Factory constructor for UpdateRequest
const
factory
UpdateRequest.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $UpdateRequestCopyWith<UpdateRequest>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of the vector.
no setterinherited
namespace String?
The namespace containing the vector to update.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setMetadata Map<String, dynamic>?
Metadata to set for the vector.
no setterinherited
sparseValues SparseVector?
Vector sparse data.
no setterinherited
values List<double>?
The vector values
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

idMaxLengthValue → const int
idMinLengthValue → const int
Validation constants
propertyNames → const List<String>
List of all property names of schema