Vector class

No Description

Annotations
  • @freezed

Constructors

Vector({required String id, required List<double> values, @JsonKey.new(includeIfNull: false) SparseVector? sparseValues, @JsonKey.new(includeIfNull: false) Map<String, dynamic>? metadata})
Factory constructor for Vector
const
factory
Vector.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $VectorCopyWith<Vector>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of the vector.
no setterinherited
metadata Map<String, dynamic>?
Metadata associated with this vector.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sparseValues SparseVector?
Sparse vector data for this vector.
no setterinherited
values List<double>
The vector values
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

idMaxLengthValue → const int
idMinLengthValue → const int
Validation constants
propertyNames → const List<String>
List of all property names of schema