VectorMatch class

No Description

Annotations
  • @freezed

Constructors

VectorMatch({required String id, @JsonKey.new(includeIfNull: false) double? score, @JsonKey.new(includeIfNull: false) List<double>? values, @JsonKey.new(includeIfNull: false) SparseVector? sparseValues, @JsonKey.new(includeIfNull: false) Map<String, dynamic>? metadata})
Factory constructor for VectorMatch
const
factory
VectorMatch.fromJson(Map<String, dynamic> json)
Object construction from a JSON representation
factory

Properties

copyWith → $VectorMatchCopyWith<VectorMatch>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of the vector.
no setterinherited
metadata Map<String, dynamic>?
This is the metadata, if it is requested.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double?
This is a measure of similarity between this vector and the query vector. The higher the score, the more they are similar.
no setterinherited
sparseValues SparseVector?
This is the sparse vector data, if it is requested.
no setterinherited
values List<double>?
This is the vector data, if it is requested.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
Map representation of object (not serialized)
toString() String
A string representation of this object.
inherited
validateSchema() String?
Perform validations on the schema property values

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

idMaxLengthValue → const int
idMinLengthValue → const int
Validation constants
propertyNames → const List<String>
List of all property names of schema