CreateIndexRequest class
No Description
- Annotations
-
- @freezed
Constructors
-
CreateIndexRequest({required String name, required int dimension, @Default.new(SearchMetric.cosine) SearchMetric metric, @Default.new(1) int pods, @Default.new(1) int replicas, @JsonKey.new(name: 'pod_type') @Default.new(PodType.p1X1) PodType podType, @JsonKey.new(name: 'metadata_config', includeIfNull: false) Map<
String, dynamic> ? metadataConfig, @JsonKey.new(name: 'source_collection', includeIfNull: false) String? sourceCollection}) -
Factory constructor for CreateIndexRequest
constfactory
-
CreateIndexRequest.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $CreateIndexRequestCopyWith<
CreateIndexRequest> -
no setterinherited
- dimension → int
-
The dimensions of the vectors to be inserted in the index.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadataConfig
→ Map<
String, dynamic> ? -
Configuration for the behavior of Pinecone's internal metadata index.
no setterinherited
- metric → SearchMetric
-
The vector similarity metric of the index.
no setterinherited
- name → String
-
The name of the index to be created.
no setterinherited
- pods → int
-
The number of pods for the index to use, including replicas.
no setterinherited
- podType → PodType
-
An enumeration of the available pod types.
no setterinherited
- replicas → int
-
The number of replicas. Replicas duplicate your index. They provide higher availability and throughput.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceCollection → String?
-
The name of the collection to create an index from.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- nameMaxLengthValue → const int
- Validation constants
- podsDefaultValue → const int
- podsMinValue → const int
-
propertyNames
→ const List<
String> - List of all property names of schema
- replicasDefaultValue → const int
- replicasMinValue → const int