DeleteRequest class
No Description
- Annotations
-
- @freezed
Constructors
-
DeleteRequest({@JsonKey.new(includeIfNull: false) List<
String> ? ids, @JsonKey.new(includeIfNull: false) bool? deleteAll, @JsonKey.new(includeIfNull: false) String? namespace, @JsonKey.new(includeIfNull: false) Map<String, dynamic> ? filter}) -
Factory constructor for DeleteRequest
constfactory
-
DeleteRequest.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $DeleteRequestCopyWith<
DeleteRequest> -
no setterinherited
- deleteAll → bool?
-
This indicates that all vectors in the index namespace should be deleted.
no setterinherited
-
filter
→ Map<
String, dynamic> ? -
If specified, the metadata filter here will be used to select the vectors to delete.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ids
→ List<
String> ? -
Vectors to delete, by id.
no setterinherited
- namespace → String?
-
The namespace to delete vectors from, if applicable.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema