FetchResponse class
No Description
- Annotations
-
- @freezed
Constructors
-
FetchResponse({required String namespace, required Map<
String, Vector> vectors}) -
Factory constructor for FetchResponse
constfactory
-
FetchResponse.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $FetchResponseCopyWith<
FetchResponse> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- namespace → String
-
The namespace to the vectors.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
vectors
→ Map<
String, Vector> -
The matches for the vectors.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema