IndexDatabase class
Summary of index properties and metadata
- Annotations
-
- @freezed
Constructors
- IndexDatabase({required String name, required SearchMetric metric, required int dimension, required int replicas, required int shards, required int pods, @JsonKey.new(name: 'pod_type', includeIfNull: false, unknownEnumValue: JsonKey.nullForUndefinedEnumValue) PodType? podType})
-
Factory constructor for IndexDatabase
constfactory
-
IndexDatabase.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $IndexDatabaseCopyWith<
IndexDatabase> -
no setterinherited
- dimension → int
-
The dimension of the index.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- metric → SearchMetric
-
The vector similarity metric of the index.
no setterinherited
- name → String
-
The name of the index.
no setterinherited
- pods → int
-
The number of index pods.
no setterinherited
- podType → PodType?
-
An enumeration of the available pod types.
no setterinherited
- replicas → int
-
The number of index replicas.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
The number of index shards.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema