IndexStats class
Information regarding status of the index.
- Annotations
-
- @freezed
Constructors
-
IndexStats({@JsonKey.new(includeIfNull: false) Map<
String, NamespaceStats> ? namespaces, @JsonKey.new(includeIfNull: false) int? dimension, @JsonKey.new(includeIfNull: false) double? indexFullness, @JsonKey.new(includeIfNull: false) int? totalVectorCount}) -
Factory constructor for IndexStats
constfactory
-
IndexStats.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $IndexStatsCopyWith<
IndexStats> -
no setterinherited
- dimension → int?
-
The dimension of the indexed vectors.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexFullness → double?
-
The fullness of the index, regardless of whether a metadata filter expression was passed. The granularity of this metric is 10%.
no setterinherited
-
namespaces
→ Map<
String, NamespaceStats> ? -
A mapping for each namespace in the index from the namespace name to a summary of its contents.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalVectorCount → int?
-
Indicator of index readiness.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
propertyNames
→ const List<
String> - List of all property names of schema