QueryRequest class
No Description
- Annotations
-
- @freezed
Constructors
-
QueryRequest({@JsonKey.new(includeIfNull: false) String? namespace, @Default.new(10) int topK, @JsonKey.new(includeIfNull: false) Map<
String, dynamic> ? filter, @Default.new(false) bool includeValues, @Default.new(false) bool includeMetadata, @JsonKey.new(includeIfNull: false) List<double> ? vector, @JsonKey.new(includeIfNull: false) SparseVector? sparseVector, @JsonKey.new(includeIfNull: false) String? id}) -
Factory constructor for QueryRequest
constfactory
-
QueryRequest.fromJson(Map<
String, dynamic> json) -
Object construction from a JSON representation
factory
Properties
-
copyWith
→ $QueryRequestCopyWith<
QueryRequest> -
no setterinherited
-
filter
→ Map<
String, dynamic> ? -
The filter to apply. You can use vector metadata to limit your search.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The unique ID of the vector to be used as a query vector.
no setterinherited
- includeMetadata → bool
-
Indicates whether metadata is included in the response as well as the ids.
no setterinherited
- includeValues → bool
-
Indicates whether vector values are included in the response.
no setterinherited
- namespace → String?
-
The namespace to query.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sparseVector → SparseVector?
-
Vector sparse data. Represented as a list of indices and a list of corresponded values, which must be the same length.
no setterinherited
- topK → int
-
The number of results to return for each query.
no setterinherited
-
vector
→ List<
double> ? -
The query vector. This should be the same length as the dimension of the index being queried.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> - Map representation of object (not serialized)
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSchema(
) → String? - Perform validations on the schema property values
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- idMaxLengthValue → const int
- idMinLengthValue → const int
-
propertyNames
→ const List<
String> - List of all property names of schema
- topKDefaultValue → const int
- Validation constants
- topKMaxValue → const int
- topKMinValue → const int